package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````'!H!`#0```"<P@````0`!30`(``)
M`"@`'``;``$``'"<KP``G*\!`)RO`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"HKP``J*\```4```````$`
M`0```-R^``#<O@(`W+X"`$P"``"0$@``!@```````0`"````Z+X``.B^`@#H
MO@(`&`$``!@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DW+X`
M`-R^`@#<O@(`)`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50!@[Y![!RM*04B5PY@8%GBQZN:\X&$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`D`$D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#0````\`
M```0````$0```!,````6`````````````````````````!@````;````'```
M```````@````(0```"(`````````(P```"0````H`````````"H`````````
M`````"L````L````+0```"X`````````,@```#,`````````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:`````````%P`````````7@````````!@````80``````````
M````8P```&0```!F````9P```&H```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PF]Z:?J3K01B-^/PP4/R[\C?A2!/5Z2;EL6YG$!0&WU?
M,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^J9R;8M#Z@NPL]HMK
M?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7
MQ!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````%```````````````"````!G`P`````````````2````*@(`````````
M````$@```,$"`````````````!(```"E`@`````````````2````:`0``!C!
M`@``````(``7`)L!`````````````!(```">`@`````````````2````BP$`
M`%`5`0``````$@```-$#```HP0(``````!``&`!8`@`````````````2````
M@P(`````````````$@```*@$```DP0(`!````!$`%P`$`P`````````````2
M````]`0``"1I`0#``P``$@`-`$T$``#P6@$`(`$``!(`#0!N`P``````````
M```2````:0(`````````````$@```!4#`````````````!(```#@`P``;-$"
M```````0`!@`*P0`````````````$@```%D$``!H7P$`O`D``!(`#0""!```
MW%<!`.P````2``T`0`0``,A:`0`H````$@`-`)`"`````````````!(```!3
M`@`````````````2````9`$`````````````$@```/$"`````````````!(`
M``"!`P``*,$"``0````A`!@`$@(`````````````$@```!D"````````````
M`!(```"S`@`````````````2````O@,``"C!`@``````$``7`,X"````````
M`````!(```"'````;!<!```````2````F`(`````````````$@```#D#````
M`````````!(````,`@`````````````2````,@(`````````````$@```((#
M```HP0(`!````"$`&`#K`P``;-$"```````0`!@`#@,``$#!`@`$````$0`8
M`/@#``#0;0$`!````!(`#0!O`0`````````````2````2P$`````````````
M$@```)@$``!P;0$`8````!(`#0#4!```5%X!`!0!```2``T``@0``-1M`0``
M````$@`.`'("`````````````!(```!L!```'!H!```````2``T`P00``+@4
M`0``````$@`+`*<``````````````!(```#C`@`````````````2````ZP``
M`#S!`@`!````$0`8`*P"`````````````!(```!S!```W&T!``0````1``\`
MQ0,``"C!`@``````$``8`$`#`````````````!(```!8`P`````````````2
M````:@``````````````$@```/@``````````````!(```"_!```5%<!`#0`
M```2``T`%`$`````````````$@```/,#``!LT0(``````!``&`#'!```S%@!
M`/P!```2``T`O```````````````$@```$$"`````````````!(```#X`0``
M```````````2````?0$`````````````$@```,H``````````````!(```#<
M```````````````2````"0$``#C!`@`$````$0`8`(`#```HP0(`!````!$`
M&``]`0`````````````2````N@(`````````````$@```-\#``!LT0(`````
M`!``&`#F!```P%T!`'P````2``T`F```````````````$@```/P"````````
M`````!(```!F!```&,$"```````0`!<`2@,`````````````$@```)X#```P
MP0(`!````!$`&``9!```/%X!`!@````2``T`N0$`````````````$@```*8!
M`````````````!(```![`P``\!<!`"P"```2``T`&0$`````````````$@``
M`"4#`````````````!(````<`P`````````````2````Q`$``$3!`@`3````
M$0`8`-P"`````````````!(```#(`@`````````````2````8`(`````````
M````$@```+(!`````````````!(```!@`P`````````````2````L@0``!!<
M`0"P`0``$@`-`"P#`````````````!(````>`0`````````````2````B@(`
M````````````$@```#0$``#D;`$`=````!(`#0!X```````````````2````
M6P$`````````````$@````@$``#(6`$`!````!(`#0`J`0``]!8!```````2
M`````&QI8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K
M7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P
M=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`
M7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G
M:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE
M;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER
M`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V
M-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`&5X
M96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?
M8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`;&0M;&EN=7@M87)M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R
M9`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R
M=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````
M```````````"``,``@`"``$````"`````0`"``(``0`"``$``0`"``(``@`!
M``(``0`!``$``@`"`````@`"``,``P`"``$``@````(``@`#``,``@`!``(`
M`0```````0`!``$``@`!``$````"`````@`!``$``@`"```````!`````0`!
M`````@`#`````````````@````(``0`!`````@`!``(`!``!```````!``(`
M`@`"`````@`"``(``@`"``$``@````(``0```````0````$``0"*`P``$```
M`"`````4:6D-```$``H%`````````0`!`.@!```0````(````!1I:0T```,`
M"@4````````!``$`-P(``!``````````%&EI#0```@`*!0```````!3!`@`5
M`@``*,$"`!1,```PP0(`%%4``#C!`@`42P``/,$"`!0Y``!`P0(`%"T``$3!
M`@`470``#,`"`!8'```0P`(`%@4``!3``@`6&```&,`"`!8J```<P`(`%A8`
M`"#``@`6/@``),`"`!9:```HP`(`%D4``"S``@`67@``,,`"`!9;```TP`(`
M%@P``#C``@`67P``/,`"`!91``!`P`(`%D(``$3``@`6.```2,`"`!8T``!,
MP`(`%D8``%#``@`6#P``5,`"`!8<``!8P`(`%B\``%S``@`630``8,`"`!9<
M``!DP`(`%F0``&C``@`620``;,`"`!97``!PP`(`%@8``'3``@`66```>,`"
M`!92``!\P`(`%B$``(#``@`680``A,`"`!84``"(P`(`%C```(S``@`6`@``
MD,`"`!8(``"4P`(`%AT``)C``@`6(P``G,`"`!9H``"@P`(`%B@``*3``@`6
M(@``J,`"`!94``"LP`(`%C<``+#``@`68```M,`"`!8>``"XP`(`%F8``+S`
M`@`63@``P,`"`!9K``#$P`(`%C\``,C``@`690``S,`"`!8*``#0P`(`%B4`
M`-3``@`60```V,`"`!8+``#<P`(`%F(``.#``@`6.@``Y,`"`!9(``#HP`(`
M%B8``.S``@`6/0``\,`"`!9*``#TP`(`%FD``/C``@`6$0``_,`"`!8.````
MP0(`%B<```3!`@`6*0``",$"`!8?```,P0(`%A4``!#!`@`61P``"$`MZ64!
M`.L(@+WH!.`MY03@G^4.X(_@"/"^Y2RK`0``QH_B&LJ,XBS[O.4`QH_B&LJ,
MXB3[O.4`QH_B&LJ,XAS[O.4`QH_B&LJ,XA3[O.4`QH_B&LJ,X@S[O.4`QH_B
M&LJ,X@3[O.4`QH_B&LJ,XOSZO.4`QH_B&LJ,XO3ZO.4`QH_B&LJ,XNSZO.4`
MQH_B&LJ,XN3ZO.4`QH_B&LJ,XMSZO.4`QH_B&LJ,XM3ZO.4`QH_B&LJ,XLSZ
MO.4`QH_B&LJ,XL3ZO.4`QH_B&LJ,XKSZO.4`QH_B&LJ,XK3ZO.4`QH_B&LJ,
MXJSZO.4`QH_B&LJ,XJ3ZO.4`QH_B&LJ,XISZO.4`QH_B&LJ,XI3ZO.4`QH_B
M&LJ,XHSZO.4`QH_B&LJ,XH3ZO.4`QH_B&LJ,XGSZO.4`QH_B&LJ,XG3ZO.4`
MQH_B&LJ,XFSZO.4`QH_B&LJ,XF3ZO.4`QH_B&LJ,XESZO.4`QH_B&LJ,XE3Z
MO.4`QH_B&LJ,XDSZO.4`QH_B&LJ,XD3ZO.4`QH_B&LJ,XCSZO.4`QH_B&LJ,
MXC3ZO.4`QH_B&LJ,XBSZO.4`QH_B&LJ,XB3ZO.4`QH_B&LJ,XASZO.4`QH_B
M&LJ,XA3ZO.4`QH_B&LJ,X@SZO.4`QH_B&LJ,X@3ZO.4`QH_B&LJ,XOSYO.4`
MQH_B&LJ,XO3YO.4`QH_B&LJ,XNSYO.4`QH_B&LJ,XN3YO.4`QH_B&LJ,XMSY
MO.4`QH_B&LJ,XM3YO.4`QH_B&LJ,XLSYO.4`QH_B&LJ,XL3YO.4`QH_B&LJ,
MXKSYO.4`QH_B&LJ,XK3YO.4`QH_B&LJ,XJSYO.4`QH_B&LJ,XJ3YO.4`QH_B
M&LJ,XISYO.4`QH_B&LJ,XI3YO.4`QH_B&LJ,XHSYO.4`QH_B&LJ,XH3YO.4`
MQH_B&LJ,XGSYO.4`QH_B&LJ,XG3YO.4`QH_B&LJ,XFSYO.4`QH_B&LJ,XF3Y
MO.4`QH_B&LJ,XESYO.4`QH_B&LJ,XE3YO.4`QH_B&LJ,XDSYO.4`QH_B&LJ,
MXD3YO.4`QH_B&LJ,XCSYO.4`QH_B&LJ,XC3YO.4`QH_B&LJ,XBSYO.4`QH_B
M&LJ,XB3YO.7P0"WI)-!-XN11G^44`(WE$!"-Y0`PE>4,((WE$!"-X@P@C>(4
M`(WB'#"-Y9G__^O`(9_EP`&?Y0(0H.%)%0#KN#&?Y0!@T^4``%;CL$&?%0D`
M`!IK___KJ"&?Y0``4./H#P+E8```"I1!G^5!___K``"4Y=[__^N-9L#E``"4
MY=O__^L`(*#A``"4Y1XTTN4",(/C'C3"Y=7__^L4,)WE!3"#X@<!<^,>)-#E
M`2""XQXDP.5!``"*`P&@X5?__^L0P)WE0#&?Y3A!G^4`$)SE%""=Y0$`4N,`
MX*#A!`"3Y2@QG^4`$([E)!&?Y00PCN4$,*#C#!".Y?0_!.4(`([E!#",PO#O
M!.4"P8S`#!".P@,``-H$`)/D#`!3X00`H>7[__\:#<&"X@`0H./H#Q3E#C"@
MX0`0C>4#((+B#!&.Y]`0G^5W___KN#"?Y0!@4.(1```*Z`\4Y1O__^L8$(WB
MM`"?Y?P-`.N8<)_E``!0XPT```KH#Q3E`?__ZV/__^L<()WE`#"5Y08`H.$#
M`%+A%```&B30C>+P@+WHZ`\3Y7[__^L`8*#AZ?__ZNP/%^4``%#C!```"LT4
M`.OL___J6!"?Y5@`G^4^___K&!"-XE``G^7@#0#K``!0X^P/!^7C__\*\___
MZNO^_^L!`*#C(O__ZS#!`@#T%@$`;!<!`#S!`@`XP0(`4.$"`"#!`@!P<0$`
M='$!`(A7`0`@;P$`1,$"`$QP`0"\;@$``+"@XP#@H.,$$)WD#2"@X00@+>4$
M`"WE$,"?Y03`+>4,`)_E##"?Y?W^_^M9___KT&T!`/`7`0!P;0$`%#"?Y10@
MG^4#,(_@`B"3YP``4N,>_R\!^/[_ZIBE`0`4`0``'#"?Y1P`G^4#,&#@!@!3
MXQ[_+Y$0,)_E``!3XQ[_+P$3_R_A*\$"`"C!`@``````)!"?Y20`G^4!$&#@
M01&@X:$?@>#!$+#A'O\O`1`PG^4``%/C'O\O`1/_+^$HP0(`*,$"```````0
M0"WI&$"?Y0`PU.4``%/C$("]&-___^L!,*#C`##$Y1"`O>A7P0(`*`"?Y0`P
MD.4``%/C````&N+__^H8,)_E``!3X_O__PH00"WI,_\OX1!`O>C;___JY+X"
M````````````@#2?Y?!/+>F[WTWB`#"3Y3#@@.)@P(WB<%"`X@@`C>7D,HWE
M`%"-Y?"AS>$(,+[E`""=Y3._O^8$,)[E`'"@XP(`7N$#9*#A!R"@X0,<H.$"
MD*#A_R@&X@1PC.4C1*#A(WR@X0$@@N$`,*#C!R""X0DP@^'_#`3B`!"@XP`@
M@N$!,(/A`+",Y?@@S.$0P(SBY?__&FAPC>+`8(WBF."-XEC`C>+8@(WB0)"@
MX]@`[N'8(.;AV$#GX0`@(N`!,"/@V`#LX00@(N`%,"/@`"`BX`$P(^"BKZ#A
M`@"2X(.@BN$*`(#A`!"@XP&06>+X`.CA[?__&@C@G>70@<[AT"#.X=`"SN$(
MH*#A";"@X=B!SN$"8*#A\`3-X?""S>'8@,[A@U*@X=`&S>'P@<WAAD*@X="$
MS>&B787A!""%X<]?C^+00,7A`("8X`&0J>`(0)3@T`+-X0E0I>`$@*#A!9"@
MX=!!S>'XH<WA`W"@X0"@*N`!L"O@"D`$X`M0!>#X8,WA`H"8X`1@H.$%<*#A
MT"+-X=!!S>$`D*GB!B`BX`4?H.$',"/@`B"8X"01@>$$#Z#A);&@X0-PH.$'
M,*G@`8"`X0N0@>'8!LWAT*+-X?"#S>$`D*#C`*":X/B#S>$!L*O@`("@XP"0
MH.,*`*#A"Q"@X0B@H.$)L*#A^"3-X?"@S>&>OX_BT*#+X0`PH.."8J#A`*":
MX`&PJ^#8`,WA@W*@X:)]A^$!GZ#A(!&@X0`0C>4&0(?AV`'-X=ACS>$C4:#A
M!@`@X`<0(>#88,WA`&`&X`%P!^`&`*#A!Q"@X=AAS>$`8";@!J":X`%P)^`'
ML*O@V&#-X0H`H.$`H)WE)Q&@X0?/BN$$H)#@`+"KX@#`C>4$$(WET`#-X?"E
MS>$`L*#C)I&)X?"@S>$&CZ#AT*/-X0@`@.$)$('AV(3-X0"@*N#09\WA"H`(
MX`A`H.'0@,WA^`+-X=@!S>&)LJ#AJ+V+X6:?C^+0@,GA!@"0X`<0H>``8*#A
M!H"8X`%PH.$'D*G@T`/-X0A@H.$)<*#AT(#-X00`(.``0*#AB**@X0H`B^$$
M@);@`)"GX@"`F.``D*GB`W^@X2)QA^'XA,WA`F^@X0"0H.,'H(;A!;"'X0A@
MH.$)<*#AV(+-X=!%S>'8)\WA"`"@X0H`(.``0`3@!`"@X4)?C^+00,7A\*/-
MX8>RH.$"0)3@"""@X0`@(N`#4*7@`@"@X=@CS>&FO8OAAJ*@X00@DN`"0*#A
M!3"CX`H@B^$`@)3@T*#-X0"0H^("@)C@T"#-X0"0J>(J`:#A`P^`X0B@H.$"
M3Z#A"U^@X0FPH.$`@(3A"$"@X2)1A>$*@*#A(Q&@X?"ES>'0H\WA`9"%X0E0
MH.$*`*#A"Q"@X00`(.`%$"'@^$/-X=A$S>'0*,WA`)"@XP!`!.`!4`7@3!"/
MXM``P>'P0,WA*,"=Y0(`D.`#$*'@`""@X0$PH.'0`,WAB5*@X:A=A>$*`"#@
M#*"2X`"PH^*(0J#A`*":X``0H.,``*#C!""%X0=?H.$"``#JF7F"6@`````P
MP0(`\`#-X291A>$F$:#A)S&@X0`0C>4$,(WE`%"-Y0"PJ^(&3Z#A`@":X-@H
MS>'08,WA`!"KXMBCS>$$8(;A!7"'X?@$S>$&0*#A!U"@X0`0H.,`8*#A`7"@
MX0H`H.$+$*#A^$+-X00`(.`%$"'@T$7-X3#`G>4`0`3@`5`%X-8?C^+0`,'A
M\$#-X8=2H.$"`)#@`Q"AX``@H.$!,*#AT`#-X:9=A>&&0J#A"@`@X`R@DN``
ML*/B`!"@XP"@FN```*#C!""%X0E?H.'P`,WA*%&%X2@1H.$I,:#A`!"-Y00P
MC>4`4(WE"$^@X="`S>$`L*OB`@":X``0J^+8HLWA!("(X060B>$(0*#A"5"@
MX0"`H.'P!<WA"@"@X0L0H.'P0\WA!``@X`40(>#81,WAT"G-X0"0H.,`0`3@
M`5`%X*8?C^+0`,'A\$#-X3C`G>4"`)#@`Q"AX``@H.$!,*#AT`#-X8E2H.&H
M787A"@`@X`R@DN``L*/BB$*@X0"@FN``$*#C``"@XP0@A>$'7Z#A\`#-X291
MA>$F$:#A)S&@X0`0C>4$,(WE`%"-Y09/H.'08,WA`+"KX@(`FN``$*OBT*/-
MX01@AN$%<(?A!D"@X0=0H.'X!,WA`!"@XP!@H.$!<*#A"@"@X0L0H.$$`"#@
M!1`AX/A#S>'01<WAV"G-X0!`!.`!4`7@'1Z/XM``P>'P0,WAAU*@X0(`D.`#
M$*'@`""@X0$PH.'0`,WA*,"=Y:9=A>$*`"#@#*"2X`"PH^*&0J#A`*":X``0
MH.,``*#C!""%X0E?H.'P`,WA*%&%X2@1H.$I,:#A`!"-Y00PC>4`4(WE"$^@
MX="`S>$`L*OB`@":X``0J^+8H\WA!("(X060B>$(0*#A"5"@X0"`H.'P!<WA
M"@"@X0L0H.'X0LWA!``@X`40(>#81,WAT"K-X0"0H.,`0`3@`5`%X$,?C^+0
M`,'A\$#-X3#`G>4"`)#@`Q"AX``@H.$!,*#AT`#-X8E2H.&H787A"@`@X`R@
MDN``L*/BB$*@X0"@FN``$*#C``"@XP0@A>$'7Z#A\`#-X291A>$F$:#A)S&@
MX0`0C>4$,(WE`%"-Y09/H.'08,WA`+"KX@(`FN``$*OBV*+-X01@AN$%<(?A
M!D"@X0=0H.'X!,WA`!"@XP!@H.$!<*#A"@"@X0L0H.$$`"#@!1`AX/!#S>'0
M1<WAV"K-X3C`G>4`0`3@`5`%X$`0C^+0`,'A\$#-X8=2H.$"`)#@`Q"AX``@
MH.$!,*#AT`#-X:9=A>&&0J#A"@`@X`R@DN``L*/B`!"@XP"@FN```*#C`P``
MZIEY@EH`````F7F"6@`````$((7A"5^@X?``S>$H487A*!&@X2DQH.$`L*OB
M`!"-Y0(`FN`(3Z#A`%"-Y00PC>70*\WAT(#-X0`0J^+0H\WA!("(X060B>$(
M0*#A"5"@X0"`H.'P!<WA"@"@X0L0H.'X0\WA!``@X`40(>#81,WA`)"@XRC`
MG>4`0`3@`5`%X)`03^+0`,'A\$#-X8E2H.$"`)#@`Q"AX``@H.$!,*#AT`#-
MX:A=A>&(0J#A"@`@X`R@DN``L*/B`!"@XP"@FN```*#C!""%X0=?H.'P`,WA
M)E&%X281H.$G,:#A`!"-Y00PC>4`4(WE!D^@X=!@S>$`L*OB`@":X``0J^+8
MH\WA!&"&X05PA^$&0*#A!U"@X?@$S>$`$*#C`&"@X0%PH.$*`*#A"Q"@X?A"
MS>$$`"#@!1`AX-!%S>'8*\WA,,"=Y0!`!.`!4`7@5A]/XM``P>'P0,WAAU*@
MX0(`D.`#$*'@`""@X0$PH.'0`,WAIEV%X89"H.$*`"#@#*"2X`"PH^(`$*#C
M`*":X```H.,$((7A"5^@X?``S>$H487A*!&@X2DQH.$`$(WE!#"-Y0!0C>4(
M3Z#AT(#-X0"PJ^("`)K@`!"KXMBBS>$$@(CA!9")X0A`H.$)4*#A`("@X?`%
MS>$*`*#A"Q"@X00`(.`%$"'@\$/-X=A$S>'0+,WA`)"@XP!`!.`!4`7@AA]/
MXM``P>'P0,WA.,"=Y0(`D.`#$*'@`""@X0$PH.'0`,WAB5*@X:A=A>$*`"#@
M#*"2X`"PH^*(0J#A`*":X``0H.,``*#C!""%X0=?H.'P`,WA)E&%X281H.$G
M,:#A`!"-Y00PC>4`4(WE!D^@X=!@S>$`L*OB`@":X``0J^+0H\WA!&"&X05P
MA^$&0*#A!U"@X?@$S>$`$*#C`&"@X0%PH.$*`*#A"Q"@X?A#S>$$`"#@!1`A
MX-!%S>'8+,WA*,"=Y0!`!.`!4`7@N1]/XM``P>'P0,WAAU*@X0(`D.`#$*'@
M`""@X0$PH.'0`,WAIEV%X89"H.$*`"#@#*"2X`"PH^(`$*#C`*":X```H.,$
M((7A"5^@X?``S>$H487A*!&@X2DQH.$`$(WE!#"-Y0!0C>4(3Z#AT(#-X0"P
MJ^("`)K@`!"KXMBCS>$$@(CA!9")X0A`H.$)4*#A`("@X?`%S>$*`*#A"Q"@
MX00`(.`%$"'@^$+-X=A$S>'0+<WA`)"@XP!`!.`!4`7@UQ^/XM``P>'P0,WA
M,,"=Y0(`D.`#$*'@`""@X0$PH.'0`,WAB5*@X:A=A>$*`"#@#*"2X`"PH^*(
M0J#A`*":X``0H.,``*#C!""%X0=?H.'P`,WA)E&%X281H.$G,:#A`+"KX@`0
MC>4"`)K@!D^@X0!0C>4$,(WEV"W-X=!@S>$`$*OBV*+-X01@AN$%<(?A^`3-
MX09`H.$'4*#A`!"@XP!@H.$!<*#A"@"@X0L0H.'P0\WA!``@X`40(>#01<WA
M.,"=Y0!`!.`!4`7@*1Z/XM``P>'P0,WAAU*@X0(`D.`#$*'@`""@X0$PH.'0
M`,WAIEV%X89"H.$*`"#@#*"2X`"PH^(`$*#C`*":X```H.,$((7A"5^@X?``
MS>$H487A*!&@X2DQH.$`$(WE!#"-Y0!0C>4(3Z#AT(#-X0"PJ^("`)K@`!"K
MXM"CS>$$@(CA!9")X0A`H.$)4*#A`("@X?`%S>$*`*#A"Q"@X?A#S>$$`"#@
M!1`AX-A$S>'0+LWA`)"@XP!`!.`!4`7@'1Z/XM``P>'P0,WA*,"=Y0(`D.`#
M$*'@`""@X0$PH.'0`,WAB5*@X:A=A>$*`"#@#*"2X`"PH^*(0J#A`*":X``0
MH.,``*#C!""%X0=?H.'P`,WA)E&%X281H.$G,:#A`!"-Y00PC>4`4(WE!D^@
MX=!@S>$`L*OB`@":X``0J^+8H\WA!&"&X05PA^$&0*#A!U"@X?@$S>$`$*#C
M`&"@X0%PH.$*`*#A"Q"@X00`(.`%$"'@^$+-X=!%S>'8+LWA`$`$X`%0!>!"
M'X_BT`#!X?!`S>$PP)WE`@"0X`,0H>``(*#A`3"@X=``S>&'4J#AIEV%X0H`
M(.`,H)+@`+"CXH9"H.$`H)K@`!"@XP``H.,$((7A"5^@X?``S>$H487A`+"K
MXB@1H.$"`)K@*3&@X0`0C>4$,(WE`%"-Y0`0J^(`H*#A`+"@XPA/H.'0@,WA
M\*#-X=BBS>$$@(CA!9")X?`%S>$*`*#AT"_-X?"#S>$(`"#@7)"/XM"`R>'8
M1,WA.,"=Y0*`F.`#D*G@"""@X0DPH.'0@,WA`$`$X`2@*N`*`*#A#*"2X*@M
MH.&(0J#AB2*"X0"PH^($((+A`*":X`"PJ^('7Z#A`H":X`"0J^(&``#J``"@
MX9EY@EH`````F7F"6@````"AZ]EN`````"91A>$&3Z#A!6"$X0:@H.'XA,WA
M"&"@X="#S>$G$:#A`7"%X=`%S>$(0*#A"D`DX`0``.#8+\WA`$"@X5003^+0
M`,'A!["@X0!PH.,"`)#@*,"=Y?BCS>$`(*#AA[*@X0,0H>"FO8OA#""2X(:B
MH.$$@"C@`#"AX@H`B^$(@)+@`)"CX@"@F.``L*GBT(#-X?"ES>$!'(WB"5^@
MX2A1A>$(3Z#A*3&@X0J`H.$#L(7A!:"$X0H@H.$+,*#AT`#!X?`@S>'4,$_B
MT"##X=A#S>$`D*#C`""2X`$PH^#8!,WA"D`DX##`G>4$`"#@B;*@X0!`H.&H
MO8OA#`"2X(BBH.$`$*/B"B"+X00`D.``$*'B`J"0X`"PH>('7Z#A)E&%X09/
MH.$G,:#A"F"@X?BDS>$%H(3A`["%X=!`S>$*(*#A"S"@X4(?C>(*0"3@T`#!
MX?@BS>'0I<WA6C]/XM`@P^$`<*#C.,"=Y0`@DN`$H"K@A[*@X0$PH^`*0*#A
M#`"2X*:]B^&&HJ#A`!"CX@H@B^$$`)#@`!"AX@*@D.``L*'B"5^@X2A1A>$(
M3Z#A*3&@X?BCS>$*@*#A`["%X06@A.'80LWA"B"@X0LPH.$1'HWB\"/-X=``
MP>$*0"3@>S]/XM`@P^'8I,WA`)"@XP#`G>4`()+@!*`JX(FRH.$!,*/@"D"@
MX0P`DN"HO8OAB**@X0`0H^(*((OA!`"0X``0H>("H)#@`+"AX@=?H.$F487A
M!D^@X2<QH.'XI,WA"F"@X0.PA>$%H(3AT$/-X0H@H.$+,*#A1A^-XO`@S>'0
M`,'A"D`DX)T_3^+0(,/AV*/-X0!PH.,HP)WE`""2X`2@*N"'LJ#A`3"CX`I`
MH.$,`)+@IKV+X8:BH.$`$*/B"B"+X00`D.``$*'B`J"0X`"PH>()7Z#A*%&%
MX0A/H.$I,:#A"H"@X?BCS>$%H(3A`["%X=!`S>$*(*#A"S"@X1(>C>+X(LWA
MT`#!X0I`)."_/T_BT"##X=BDS>$`D*#C,,"=Y0`@DN`$H"K@B;*@X0$PH^`*
M0*#A#`"2X*B]B^&(HJ#A`!"CX@H@B^$$`)#@`!"AX@*@D.``L*'B!U^@X291
MA>$&3Z#A)S&@X0I@H.'XI,WA!:"$X0.PA>'80LWA"B"@X0LPH.%*'XWB\"/-
MX=``P>$*0"3@W3^/XM`@P^'8H\WA`'"@XP#`G>4`()+@!*`JX(>RH.$!,*/@
M"D"@X0P`DN"FO8OAAJ*@X0`0H^(*((OA!`"0X``0H>("H)#@`+"AX@E?H.$H
M487A"$^@X2DQH.$*@*#A^*/-X06@A.$#L(7AT$/-X0H@H.$+,*#A$QZ-X@I`
M).#0`,'AV*3-X?`@S>&Z/X_BT"##X0"0H.,HP)WE`""2X`2@*N")LJ#A`3"C
MX`I`H.$,`)+@J+V+X8BBH.$`$*/B"B"+X00`D.``$*'B`J"0X`"PH>('7Z#A
M3A^-XB91A>$&3Z#A)S&@X=``P>$*8*#A^*3-X06@A.$#L(7AT$#-X0H@H.$+
M,*#A"D`DX/@BS>'8H\WA)CZ/XM`@P^$`<*#C,,"=Y0`@DN`$H"K@A[*@X0$P
MH^`*0*#A#`"2X*:]B^&&HJ#A`!"CX@H@B^$$`)#@`!"AX@*@D.``L*'B"5^@
MX2A1A>$(3Z#A*3&@X?BCS>$*@*#A`["%X06@A.'80LWA"B"@X0LPH.$%'8WB
M\"/-X=``P>$*0"3@=S^/XM`@P^'8I,WA`)"@XP#`G>4`()+@!*`JX(FRH.$!
M,*/@"D"@X0P`DN"HO8OAB**@X0`0H^(*((OA!`"0X``0H>("H)#@`+"AX@=?
MH.$F487A!D^@X2<QH.$*8*#A^*3-X06@A.$#L(7AT$/-X0H@H.$+,*#A4A^-
MXO`@S>'0`,'A"D`DX%4_C^+0(,/AV*/-X0!PH.,HP)WE`""2X`2@*N"'LJ#A
M`3"CX`I`H.$,`)+@IKV+X8:BH.$`$*/B"B"+X00`D.``$*'B`J"0X`"PH>()
M7Z#A*%&%X0A/H.$I,:#A"H"@X?BCS>$%H(3A`["%X=!`S>$*(*#A"S"@X14>
MC>+X(LWAT`#!X0I`).#,,(_BT"##X=BDS>$`D*#C,,"=Y0`@DN`$H"K@B;*@
MX0$PH^`*0*#A#`"2X*B]B^&(HJ#A`!"CX@H@B^$$`)#@`!"AX@*@D.``L*'B
M!U^@X291A>$&3Z#A)S&@X0I@H.'XI,WA!:"$X0.PA>'80LWA"B"@X0LPH.%6
M'XWB"D`DX-``P>'8H\WA\"/-X4`PC^+0(,/A`'"@XP#`G>4`()+@!*`JX(>R
MH.$!,*/@"D"@X0P`DN"FO8OAAJ*@X0`0H^(*((OA!`"0X``0H>()7Z#A`P``
MZJ'KV6X`````H>O9;@`````"H)#@%LZ-X@"PH>(H487A*3&@X0H`H.$+$*#A
M`Y"%X="@S.$T,$_BT"##X0A/H.$%@(3A"$"@X0H@DN#X`\WA"5"@X="#S>$+
M,*/@V*3-X0`0H.,HP)WE!(`HX/!`S>$(H"K@`U"@X8$RH.$*@*#AH#V#X0R@
MDN"`(J#A`+"EX@,@@N$(H)K@`+"KX@*`FN``D*OB6L^-X@=?H.$F487A!D^@
MX2<QH.'XA,WA"&"@X="@S.$%@(3A`Y"%X<Q03^+00,7A"""@X0DPH.$*0)3@
MT(#-X0M0I>#8H\WA`'"@XS#`G>4"@"C@^"+-X0B@*N"',J#A"H"@X:8]@^$,
MH)3@AB*@X0"PI>(#((+A"*":X`"PJ^("@)K@`)"KXE[/C>(!7Z#A(%&%X2$Q
MH.'8H$SA^(/-X0.0A>%2/T_BT"##X0!/H.$(`*#A!8"$X0A`H.$)4*#A"B"2
MX-B"S>$+,*/@V*3-X0`0H./P0\WA!(`HX`!0G>4(H"K@@;*@X0J`H.&@O8OA
M!2"2X("BH.$`,*/B"Z"*X0@@DN``,*/B"H"2X`"0H^('7Z#A)E&%X09/H.$G
M,:#A"&"@X?B$S>$%@(3A`Y"%X0A`H.$)4*#AT(/-X="@S.'P0,WA!(`HX'M?
M3^+00,7A`'"@XRC`G>4*0)3@"U"EX-BCS>&',J#AICV#X0B@*N`*@*#AAB*@
MX0R@E.``L*7B`R""X0B@FN``L*OB`H":X`"0J^)BSXWB`5^@X2!1A>$`3Z#A
M(3&@X0@`H.'8H$SA\(7-X06`A.$#D(7A)EY/XM!`Q>$((*#A"3"@X0I`E.#0
M@,WA"U"EX-BDS>$`$*#C^"+-X0*`*.`%,*#A,%"=Y0B@*N"!LJ#A!2"4X`J`
MH.&@O8OA@**@X0`PH^(+H(KA"""2X``PH^(*@)+@`)"CX@=?H.$F487A!D^@
MX2<QH.$(8*#A\(/-X06`A.$#D(7A"$"@X0E0H.'8@LWAT*#,X?A#S>$$@"C@
MOU]/XM!`Q>$`<*#CAB*@X0I`E.`+4*7@T*7-X0#`G>6',J#A"*`JX`J`H.&F
M/8/A#*"4X`"PI>(#((+A"*":X`"PJ^("@)K@`)"KXF;/C>(!7Z#A(%&%X2$Q
MH.'8H$SA\(7-X0.0A>'9/T_BT"##X0!/H.$(`*#A!8"$X0A`H.$)4*#A"B"2
MX-B#S>$+,*/@T*/-X0`0H./X1,WA!(`HX"A0G>4(H"K@@;*@X0J`H.&@O8OA
M!2"2X("BH.$`,*/B"Z"*X0@@DN``,*/B"H"2X`"0H^('7Z#A)E&%X2<QH.'0
MH,SA^(+-X0.0A>'6/X_BT"##X09/H.$`<*#C"&"@X0H@DN`%@(3AV$3-X0LP
MH^#0I<WAA\*@X:;-C.$(0"3@!,"-Y02@*N`,0*#A.,"=Y?"#S>$,()+@`#"C
MX@J@DN``L*/BAL*@X0#`C>7XH\WAT*#-X6K/C>(!GZ#A!*"*X0I`H.'8H\WA
M()&)X2$QH.$$H)K@`+"KX@I`H.$+4*#AV*!,X0"/H.'8`LWA\*#-X0.PB>'0
M(\WA":"(X?!%S>$$@*#A"U"#X0I`@N$$``#@!1`!X`!`H.$!4*#A"B`"X*,?
MC^+0`,'A"S`#X/BCS>'0H,WA`)"@XP"@FN`!L*O@"@"@X0L0H.$$H(+A!;"#
MX4@PG>7PH,WA`T"0X``PG>4`4*'B`""@XP-`E.``,*#CB;*@X?`@S>&HO8OA
M!S^@X8BBH.$$,(WE"Z"*X0!0I>(*`)3@!$"=Y0`0I>(F083A!$"-Y00@H.$&
M3Z#A`$"-Y0!@H.'X!,WAT`#-X2<QH.'0H,SA`@"`X0,0@>$`0*#A`5"@X=@#
MS>'X0LWA,,"=Y00@@.'01<WA`#"@XP!PH.,"0`3@!""@X0!`H.'8`LWAAU*@
MX:9=A>$`0`3@&AZ/XM``P>$$((+AAD*@X0H`D.`+$*'@#*"0X`"PH>("H)K@
M`""@XP0`A>'P(,WA"3^@X00PC>4$$)WE*5&@X2@1@>$$$(WE`4"@X0@?H.$`
M$(WET(#-X0"PJ^(`()K@`#"KX@2`B.$(0*#A\"7-X0*`H.'8(LWA!9")X0E0
MH.$$H(+A!;"#X?!#S>$*0*#A"U"@X=BDS>%NSXWB`)"@XP2@"N`%L`O@"D"@
MX0M0H.'0H\WAV`!,X0H@`N`+,`/@X+"/XM"@R^$`H)K@`;"KX`H`H.$+$*#A
M!*""X06P@^$X,)WE\*#-X0-`D.``,)WE`%"AX@`@H.,#0)3@`#"@XXFRH.'P
M(,WAJ+V+X0<_H.&(HJ#A!#"-Y0N@BN$`4*7B"@"4X`1`G>4`$*7B)D&$X01`
MC>4$(*#A!D^@X0!`C>4`8*#A^`3-X=``S>'0H,SA)S&@X=!#S>$"`(#A`Q"!
MX0`@H.$!,*#A`@"$X?@CS>$`(*#AT`7-X0!PH.,HP)WE`@``X``@H.'8`\WA
MAU*@X:9=A>$`0`3@!```Z@``H.&AZ]EN`````-R\&X\`````$!!/XM``P>$$
M((+A`#"@XPH`D.`+$*'@#*"0X`"PH>*&0J#A`J":X``@H.,$`(7A`D"@X0-0
MH.$)/Z#A\$#-X2@Q@^$`L*OB*,&@X0!`FN`I$:#A`,"-Y000C>4`,(WE`%"K
MX@2@H.$%L*#AT$#-X0@OH.'PI<WA`D"$X0-0A>'8(\WA"H"@X?A"S>$$H(+A
M!;"#X0I`H.$+4*#AV*3-X7+/C>(`D*#C!*`*X`6P"^`*0*#A"U"@X=BBS>'8
M`$SA"B`"X`LP`^#8L$_BT*#+X0"@FN`!L*O@"@"@X0L0H.$$H(+A!;"#X3`P
MG>7PH,WA`T"0X``PG>4`4*'B`""@XP-`E.``,*#CB;*@X?`@S>&HO8OA!S^@
MX8BBH.$$,(WE"Z"*X0!0I>(*`)3@!$"=Y0`0I>(F083A!$"-Y00@H.$&3Z#A
M`$"-Y0!@H.'X!,WAT`#-X=A"S>$G,:#A`@"`X0,0@>$`(*#A`3"@X0(`A.'P
M(\WA`""@X=`%S>'0H,SA`'"@XP(``.``(*#AT`/-X3C`G>6'4J#A`$`$X&L?
M3^+0`,'A!"""X:9=A>$*`)#@"Q"AX`R@D.``L*'BAD*@X0*@FN``,*#C`""@
MXP0`A>$"0*#A`U"@X0D_H.'P0,WA*#&#X0"PJ^(HP:#A`$":X"D1H.$`P(WE
M!!"-Y0`PC>4`4*OB!*"@X06PH.'00,WA""^@X?"ES>$"0(3A`U"%X=`CS>$*
M@*#A^$/-X02@@N$%L(/A"D"@X0M0H.'8I,WA=L^-X@"0H.,$H`K@!;`+X`I`
MH.$+4*#AV*/-X=@`3.$*(`+@"S`#X)Z_3^+0H,OA`*":X`&PJ^`*`*#A"Q"@
MX02@@N$%L(/A*#"=Y?"@S>$#0)#@`#"=Y0!0H>(`(*#C`T"4X``PH..)LJ#A
M\"#-X:B]B^$'/Z#AB**@X00PC>4+H(KA`%"EX@H`E.`$0)WE`!"EXB9!A.$$
M0(WE!""@X09/H.$`0(WE`&"@X?@$S>'0`,WAV$/-X2<QH.$"`(#A`Q"!X0`@
MH.$!,*#A`@"$X?@BS>$`(*#AT`7-X="@S.$`<*#C`@``X``@H.'8`LWA,,"=
MY8=2H.$`0`3@TQ]/XM``P>$$((+AIEV%X0H`D.`+$*'@#*"0X`"PH>*&0J#A
M`J":X``PH.,`(*#C!`"%X0)`H.$#4*#A"3^@X?!`S>$H,8/A`+"KXBC!H.$`
M0)K@*1&@X0#`C>4`4*OB`#"-Y000C>4$H*#A!;"@X=!`S>%ZSXWB""^@X=@`
M3.$"0(3A\*7-X0-0A>'8(LWA"H"@X?!#S>$$H(+A!;"#X0I`H.$+4*#AV*3-
MX0"0H.,$H`K@!;`+X`I`H.$+4*#AT*/-X0H@`N`+,`/@-;Z/XM"@R^$`H)K@
M`;"KX`H`H.$+$*#A!*""X06P@^$X,)WE\*#-X0-`D.``,)WE`%"AX@`@H.,#
M0)3@`#"@XXFRH.'P(,WAJ+V+X0<_H.&(HJ#A!#"-Y0N@BN$`4*7B"@"4X`1`
MG>4`$*7B)D&$X01`C>4$(*#A!D^@X0!`C>4`8*#A^`3-X=``S>'00\WA)S&@
MX0(`@.$#$('A`""@X0$PH.$"`(3A^"/-X0`@H.'0!<WAT*#,X0!PH.,"``#@
M`""@X=@#S>$HP)WEAU*@X0!`!."?'X_BT`#!X:9=A>$`4(WE"@"0X`L0H>`,
M`)#@I\V@X03`C>4$((+A`!"AX@*@D.#0(,WAAD*@X0"PH>($((+A`J":X`"P
MJ^(*0*#A"U"@X0D?H.$H$8'A"`^@X2DQH.$$@*#A`)"@X_!%S>$!0(#A`U"!
MX=@#S>'P@,WAV(3-X00@@.$?SHWB`H`(X-"@S.$((*#A>I^/XM"`R>$$``#@
M^$+-X0J`F.`+D*G@`$"@X0D0H.$(`*#AT(#-X3#`G>4$((+AB5*@X0P`D."H
M787AB$*@X7[/C>(`$*'B!4"$X0*`D.``D*'B!("8X-!`S.$''Z#A)A&!X08/
MH.$G,:#A^$7-X0%`@.$#4('A!`"@X040H.'80LWA`)"IX@A@H.'0I<WA^(3-
MX0`@A.'P`\WA4Y^/XM"`R>$`0`3@V`7-X0!PH.,XP)WE"`"0X`*@"N"'4J#A
M!""*X0D0H>#0H,WA#`"0X*9=A>&&0J#A`LR-X@`0H>(%0(3A`H"0X`"0H>($
M@)C@T$#,X0L?H.$J(:#A*A&!X0LO@N$*#Z#A*S&@X?!`S>$"0(#A`U"!X=`#
MS>'8I,WA`)"IX@0@@.$"H`K@!```X/A#S>$*(*#A`$"@X:RPC^+0H,OAT`#-
MX?"%S>$`D*#C*,"=Y0H`D.")4J#A"Q"AX*A=A>$,`)#@J<V@X0!0C>4$P(WE
M!"""X0`0H>("H)#@T"#-X8+/C>*(0J#A!"""X=!`S.$`L*'B!Q^@X0*@FN`F
M$8'A!@^@X2<QH.'P0,WA`+"KX@%`@.$#4('A!`"@X040H.'80\WA"F"@X?BD
MS>'0I<WA`""$X?@"S>$"H`K@`$`$X`H@H.'0`,WA`P``ZMR\&X\`````W+P;
MCP`````0L$_BT*#+X0!PH.,PP)WE"@"0X(=2H.$+$*'@IEV%X0P`D."GS:#A
M`%"-Y03`C>4$((+A`!"AX@*@D.#0(,WAAD*@X2'.C>($((+A`+"AXM!`S.$"
MH)K@`+"KX@D?H.$H$8'A"`^@X2DQH.'P0,WA\*7-X0%`@.$#4('AV`+-X0J`
MH.'8I,WA!""`X00``.`"H`K@\$/-X0H@H.$`0*#AT*#-X;003^+0`,'A`)"@
MXSC`G>4`H)K@B5*@X0&PJ^"H787A#`":X*G-H.$`4(WE!,"-Y00@@N$`$*OB
M`J"0X-`@S>&&SXWBB$*@X00@@N'00,SA`+"AX@<?H.$"H)K@)A&!X08/H.$G
M,:#A\$#-X0"PJ^(!0(#A`U"!X00`H.$%$*#AT$/-X0I@H.'XI,WAT*7-X0`@
MA.'X`\WA`J`*X`!`!.`*(*#AT`#-X5>_3^+0H,OA`'"@XRC`G>4*`)#@AU*@
MX0L0H>"F787A#`"0X*?-H.$`4(WE!,"-Y00@@N$`$*'B`J"0X-`@S>$BSHWB
MAD*@X00@@N'00,SA`+"AX@*@FN`)'Z#A*!&!X0"PJ^((#Z#A*3&@X?!`S>$!
M0(#A`U"!X=@#S>$*@*#A\*7-X=BDS>$$((#A!```X`*@"N#X0LWA"B"@X0!`
MH.'0H,WA`AQ/XM``P>$`D*#C,,"=Y0"@FN")4J#A`;"KX*A=A>$,`)K@J<V@
MX0!0C>4$P(WE!"""X0`0J^("H)#@T"#-X8K/C>*(0J#A!"""X=!`S.$`L*'B
M`J":X`<?H.$F$8'A`+"KX@8/H.$G,:#A\$#-X0%`@.$#4('A^*3-X00`H.$%
M$*#AV$+-X0I@H.'0I<WA`""$X?`#S>$"H`K@`$`$X`H@H.'0`,WAJK]/XM"@
MR^$`<*#C.,"=Y0H`D."'4J#A"Q"AX*9=A>$,`)#@I\V@X0!0C>4$P(WE!"""
MX0`0H>("H)#@T"#-X2/.C>*&0J#A!"""X=!`S.$`L*'B`J":X`D?H.$H$8'A
M`+"KX@@/H.$I,:#A\$#-X0%`@.$#4('AT`/-X0J`H.'PI<WAV*3-X00@@.$$
M``#@`J`*X/A#S>$*(*#A`$"@X=*_3^+0H,OAT`#-X0"0H.,HP)WE"@"0X(E2
MH.$+$*'@J%V%X0P`D."IS:#A`%"-Y03`C>4$((+A`!"AX@*@D.#0(,WAB$*@
MX0"PH>($((+A`J":X`"PJ^(*0*#A"U"@X0<?H.$F$8'A)S&@X08/H.$`<*#C
M^$3-X0%@@.$'4*#A`W"!X08`H.$'$*#AV&/-X?@"S>&.SXWB`""&X=`%S>'0
MH,SA,#"=Y0(``.``(*#AV`+-X0G-C>(`8`;@VQ^/XM``P>$"8(;A"@"0X`L0
MH>`#`)#@A;*@X:2]B^$`$*'BI3V@X08@D.``L(WE!#"-Y0`PH>("8*#A`W"@
MX=`@S>&$HJ#A"1^@X0H@@N$"8);@`'"GXB@1@>$I,:#A"`^@X0"0H./0H,SA
M\&7-X0&`@.$)<*#A`Y"!X;X?C^+0`,'A"""@X0DPH.$*`)#@V(+-X0L0H>#P
M(\WAV*3-X3C`G>4"@"C@"*`JX(<RH.$*@*#AICV#X0R@D."&(J#A`+"AXI+/
MC>((H)K@`X""X0"PJ^(%'Z#A""":X``PJ^(D$8'AT*#,X27!H.$`$(WE!,"-
MY?@DS>$$#Z#A`D"@X=`@S>$`4*#C*,"=Y0`@@N$!,(/A)AZ/XM``P>$"@*#A
M`Y"@X0H`D.#0(\WA"Q"AX-"ES>$(("+@A3*@X0*@*N#X@\WAI#V#X0J`H.&$
M(J#A#*"0X`"PH>((H)K@`X""X0"PJ^((`)K@`!"KX@&0H.$''Z#A)A&!X000
MC>4!(*#A)1Z-X@"`H.'0H,'A!A^@X0`0C>4`8*#AT`#-X?"%S>$`D*#C)S&@
MX0EPH.'8@\WA`@"`X0,0@>$`@"C@^`+-X6T?C^+0`,'A,,"=Y8<RH.$*`)#@
M"Q"AX-BDS>&F/8/AAB*@X0B@*N`*@*#A#*"0X`"PH>*6SXWB"*":X`.`@N$`
ML*OB!1^@X0@@FN``,*OB)!&!X="@S.$EP:#A`!"-Y03`C>4$#Z#A^"3-X0)`
MH.'0(,WA`%"@XSC`G>4`((+A`3"#X1,>C^+0`,'A`H"@X0.0H.$*`)#@V"+-
MX0L0H>#0I<WA""`BX(4RH.$"H"K@\(/-X:0]@^$*@*#AA"*@X0R@D.``L*'B
M"*":X`.`@N$`L*OB""":X``PJ^(#D*#A)CZ-X@*`H.$''Z#AT*##X281@>$G
M,:#A!@^@X0`0C>4"8*#A!#"-Y?"%S>'0(,WA`)"@XPEPH.$`((+A`3"#X900
MC^+0`,'AT(/-X2C`G>4*`)#@"Q"AX-BDS>$"@"C@^"/-X0B@*N`*@*#AAS*@
MX0R@D.`%SZ#A),&,X:8]@^&&(J#A!,"-Y0"PH>((H)K@`X""X0P@H.&:SXWB
M`+"KX@@`FN``$*OBT*#,X03/H.$`P(WE`$"@X?@$S>'0`,WA)3&@X3#`G>4"
M`(#A`Q"!X0,``.K<O!N/`````-;!8LH``````("@X0&0H.'8`\WA^(+-X0!0
MH.,(`"#@`("@X2P03^+0`,'AA3*@X:0]@^$*`)#@"Q"AX-"ES>&$(J#A`)"@
MXPB@*N`*@*#A#*"0X`?/H.$FP8SA!,"-Y0"PH>((H)K@`X""X0P@H.$GSHWB
M`+"KX@@`FN``$*OBT*#,X0;/H.$`P(WE`&"@X?`%S>'0`,WA)S&@X0EPH.$"
M`(#A`Q"!X;`P3^+0(,/AV(+-X3C`G>4*()+@"S"CX-BDS>$`@"C@\`/-X0B@
M*N`#$*#AAS*@X0J`H.&F/8/A#*"2X(8BH.$`L*'BGL^-X@B@FN`#@(+A`+"K
MX@4?H.$(()K@`#"KXB01@>'0H,SA)<&@X0`0C>4$P(WE!`^@X?@DS>$"0*#A
MT"#-X0!0H.,HP)WE`"""X0$P@^'0`\WA^"/-X84RH.$"`"#@`("@X58?3^+0
M`,'AI#V#X80BH.$*`)#@"Q"AX-"ES>$(H"K@"H"@X0R@D.``L*'B"*":X`.`
M@N$`L*OB"`":X``0J^(!D*#A!Q^@X281@>$$$(WE`2"@X0H=C>(`@*#AT*#!
MX08?H.$`$(WE`&"@X=``S>$G,:#A\(7-X0(`@.$#$('A=C]/XM`@P^$`D*#C
M"7"@X0H@DN#8@\WA"S"CX-BDS>$PP)WE`(`HX`B@*N#X`LWA"H"@X0,0H.$,
MH)+@AS*@X07/H.$DP8SAICV#X88BH.$$P(WE`+"AX@B@FN`#@(+A#""@X:+/
MC>(`L*OB"`":X``0J^+0H,SA!,^@X0#`C>4`0*#A^`3-X=``S>$E,:#A`%"@
MXP(`@.$#$('A`("@X0&0H.'8`LWA\(/-X3C`G>4(`"#@`("@X2D>3^+0`,'A
MA3*@X:0]@^$*`)#@"Q"AX-"ES>&$(J#A"*`JX`J`H.$,H)#@`+"AX@B@FN`#
M@(+A`+"KX@@`FN``$*OB`9"@X0<?H.$F$8'A!!"-Y0$@H.$I'HWB`("@X="@
MP>$&'Z#A`!"-Y0!@H.'0`,WA)S&@X?"%S>$"`(#A`Q"!X<4_3^+0(,/A`)"@
MXPEPH.$*()+@T(/-X0LPH^#8I,WA`(`HX"C`G>7X`\WA"*`JX`,0H.&',J#A
M"H"@X:8]@^$,H)+@AB*@X0"PH>*FSXWB"*":X`.`@N$`L*OB!1^@X0@@FN``
M,*OB)!&!X="@S.$EP:#A`!"-Y03`C>4$#Z#A^"3-X0)`H.'0(,WA`%"@XP`@
M@N$!,(/AV`/-X?@BS>$PP)WE`@`@X`"`H.$W'H_BT`#!X84RH.&D/8/A"@"0
MX`L0H>#0I<WAA"*@X0B@*N`*@*#A#*"0X`"PH>((H)K@`X""X0"PJ^((`)K@
M`!"KX@&0H.$''Z#A)A&!X000C>4!(*#A*AZ-X@"`H.'0H,'A!A^@X0`0C>4`
M8*#AT`#-X2<QH.'PA<WA`@"`X0,0@>&[/X_BT"##X0"0H.,)<*#A"B"2X-B"
MS>$+,*/@V*3-X3C`G>4`@"C@"*`JX/`#S>$*@*#A`Q"@X0R@DN"',J#A!<^@
MX23!C.&F/8/AAB*@X03`C>4`L*'B"*":X`.`@N$,(*#AJL^-X@"PJ^((`)K@
M`!"KXM"@S.$$SZ#A`,"-Y0!`H.'X!,WAT`#-X24QH.$`4*#C`@"`X0,0@>$`
M@*#A`9"@X=`#S>'X@\WA*,"=Y0@`(.``@*#AC1^/XM``P>&%,J#AI#V#X0H`
MD.`+$*'@T*7-X80BH.$(H"K@"H"@X0R@D.``L*'B"*":X`.`@N$`L*OB"`":
MX``0J^(!D*#A!Q^@X281@>$$$(WE`2"@X2L>C>(`@*#AT*#!X08?H.$`$(WE
M`&"@X=``S>$G,:#A\(7-X0(`@.$#$('A&SZ/XM`@P^$`D*#C"7"@X0H@DN#8
M@\WA"S"CX-BDS>$`@"C@,,"=Y?@"S>$(H"K@`Q"@X8<RH.$*@*#AICV#X0R@
MDN"&(J#A`+"AX@B@FN`#@(+A`+"KXJ[/C>((()K@`#"KX@4?H.'0H,SA)!&!
MX27!H.$$#Z#A`!"-Y0)`H.$$P(WE^"3-X=`@S>$`4*#C.,"=Y0`@@N$!,(/A
MV`+-X?`CS>&%,J#A`@`@X`"`H.$!'(_BT`#!X:0]@^&$(J#A"@"0X`L0H>#0
MI<WA"*`JX`J`H.$,H)#@`+"AX@B@FN`#@(+A`+"KX@@`FN``$*OB`9"@X0<?
MH.$F$8'A!!"-Y0$@H.$+'8WB`("@X="@P>$&'Z#A`!"-Y0!@H.'0`,WA)S&@
MX?"%S>$"`(#A`Q"!X8`PC^+0(,/A`)"@XPEPH.$*()+@T(/-X0LPH^#8I,WA
M*,"=Y0"`*.`(H"K@^`/-X0J`H.$#$*#A#*"2X(<RH.$%SZ#A),&,X:8]@^&&
M(J#A!,"-Y0"PH>((H)K@`X""X0P@H.&RSXWB`+"KX@@`FN``$*OBT*#,X03/
MH.$`P(WE`$"@X00``.K6P6+*`````-;!8LH`````,,$"`/@$S>'0`,WA)3&@
MX0!0H.,"`(#A`Q"!X0`@H.$!,*#AV`/-X3#`G>7X(LWA`@`@X`"`H.%($$_B
MT`#!X84RH.&D/8/A"@"0X`L0H>#0I<WAA"*@X0B@*N`*@*#A#*"0X`"PH>((
MH)K@`X""X0"PJ^((`)K@`!"KX@&PH.$''Z#A)A&!X000C>4!(*#A+1Z-X@"@
MH.'0@,'A!A^@X0`0C>70`,WA)S&@X=ABS>$"`(#A`Q"!X<@P3^+0(,/A\*7-
MX0"PH.,(()+@V(3-X0!@)N`XP)WE!H`HX(LRH.$(8*#AJCV#X0R`DN"*(J#A
M`R""X0:`F.`"@)C@"""@X05_H.$`,*#C\`/-X21QA^$$;Z#A)1&@X?`@S>$'
M0(;A`5"'X=!@S>$$`*#A!1"@X=!#S>&V/XWBAY*@X=`@P^$`0"3@^`/-X::=
MB>%7'T_BT`#!X=!ES>$HP)WE`@"0X`1@)N`&0*#A#&"0X-``S>$$8);@T$'-
MX8""H.$(((GA`F"6X-@@S>$`,*#C"Q^@X08@DN#08LWA\"#.X=`@S>$X,)WE
M*A&!X0H/H.$"0)3@`V"6X`&`@.$&`*#AT&3-X3`PG>7,P1_E`V"6X-@AS>$.
MH*#AY.*=Y0#`G.4(()+@`%"@XP`0H.,`<*#C`#"@XPP`7N'X0,KA^`'*X?!B
MRN'P(<KA`0``&KO?C>+PC[WH#_'_ZP``4.,>_R\!L#"?Y?!'+>D`D)/E``!9
MXR8```H`4-#E``!5XST`51,!4*`3`%"@`Q,``!H`0)GE``!4XPX```H!@*#A
M`'"@X0E@H.$%(*#A!Q"@X00`H.%_\?_K``!0XP(``!H%,-3G/0!3XPL```H$
M0+;E``!4X_/__QH$`*#A\(>]Z`!0H.$!,/7E``!3XST`4Q/[__\:!5!@X.3_
M_^H&8&G@`0"%XD9AH.$`8(CE``"$X/"'O>@)`*#A\(>]Z"C!`@!P0"WI`$"@
MX7!@G^5P4)_E"-!-X@`PEN4$,(WE#1"@X00`H.'$___K``!0XPP```H`$)WE
M`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@L^4``%+C!"`#Y?O__QKM
M___J!""=Y0`PEN4#`%+A`0``&@C0C>)P@+WHOO#_ZS#!`@`HP0(`\$\MZ0%`
MH.$`(-'E]%&?Y1303>(]`%+C`4"!`@`PE>4`8*#A!`"@X0PPC>7L\/_K"!"-
MX@!PH.$&`*#AG/__ZP"`4.(]```*Y?#_ZP``5^$T``":"("=Y:R1G^4(@:#A
M``#6Y0``4.,]`%`3`0"@$P``H`,%```*!@"@X0$P\.4``%/C/0!3$_O__QH`
M`&;@`G"'X@``A^``<)GEOO#_ZV0QG^4``%#C"`"'YU(```H`()/E"!"=Y0`P
MUN4!8(;B`1&2YST`4^,``%,3`##!Y08```H!(('B`3#6Y`(0H.$``%/C/0!3
M$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!,.+E^___&@``H.,,()WE
M`#"5Y0,`4N$X```:%-"-XO"/O>@!,$CB`2#4Y```4N,!(./E^___&O+__^K$
MD)_E`+"9Y0"@F^4``%KC)P``"@@PH.$+(*#A````Z@HPH.$$$++E`:"#X@``
M4>/Z__\:`S"#X@,1H.&,,)_E`""3Y0``4N,*```*"P"@X6#P_^L``%#C``")
MY18```H*@:#A`3"*X@`@H.,#(8#G"*"-Y:G__^H!(*#C`0"@X0`@@^5T\/_K
M`#!0X@0PC>4)```*"H&@X0L0H.$((*#A)?#_ZP0PG>4#`*#A`#")Y>O__^H(
M$*#CW___Z@``X./"___J.O#_ZS#!`@`HP0(`6,$"`/!!+>EXT$WB)%&?Y0!P
M4.(`,)7E=#"-Y0(```H`,-?E``!3XP4``!IT()WE`#"5Y0,`4N$]```:>-"-
MXO"!O>A*\/_K`&!0XO;__PH&`*#AG?#_ZP``4.,D```*$S#0Y2X`4^,F```*
M$T"`X@<`H.%6\/_K`("@X00`H.%3\/_K``"(X`(`@.(^\/_KI#"?Y0`@X.,!
M$*#C!$"-Y0!PC>4`@*#A5?#_ZP@@C>(($*#A`P"@XXWP_^L!`'#C"`"@X0,`
M``H8,)WE#SH#X@$)4^,4```*!_#_ZP@`H.'D[__K!@"@X7CP_^L``%#CVO__
M&@8`H.&,\/_K!P"@X>OO_^O(___J%##0Y0``4^/.__\*+@!3X]/__QH5,-#E
M``!3X\G__PK/___JM/__Z^G__^KJ[__K,,$"`%QN`0!P0"WI`%"@X6Q`G^4`
M`)3E>?#_ZP40H.%2+X#B`P"@XV_P_^L``%#C`0``"@``H.-P@+WH``"4Y6_P
M_^M8,9#E#SH#X@$)4^,%```*``"4Y6GP_^M8,9#E#SH#X@H*4^/Q__\:!0"@
MX0(0H.,[\/_K$`]OX:`"H.%P@+WH.,$"`/!`+>D!VDWBS%"?Y0S03>(!RHWB
M`#"5Y03`C.(`8*#A`7"@X;0@G^4$$(WBL`"?Y0`PC.7,[__K``!0XQX``-H(
M,(WB`4!`X@0@@^`$,%+E``!3XQ8```H`0*#A!""@X2\0H.,$`(WB&?#_ZP``
M4.,1```*;#"?Y0``D^4^\/_K!#"@X00@C>(&$*#A(O#_ZP$ZC>($,(/B`""3
MY0`PE>4#`%+A"P``&@':C>(,T(WB\("]Z```5./G__\:)#"?Y0``D^4L\/_K
M!R"@X080H.&B[__K[?__ZI'O_^LPP0(`_P\``&1N`0`XP0(`'#"?Y1!`+>D`
M`)/E'_#_ZQ`PG^40()_E$!"?Y1!`O>C5[__J.,$"`.!M`0!0%0$`=&X!`!!`
M+>D(T$WB-$"?Y0``E.41\/_K[/__ZP``E.4.\/_K(#"?Y0`@H.,$((WE`#"-
MY10@G^44$)_EVN__ZPC0C>(0@+WH.,$"`&QQ`0`D:0$`D&X!`'!`+>D"VDWB
MS&"?Y2#03>("*HWB`#"6Y1P@@N(`,(+EF.__Z[0PG^44((WB"""-Y00PC>6H
M()_EJ#"?Y0$0H.,``(WE"`"=Y:#O_^L``%#C'```N@$ZC>(@,(/B"#!#X@@`
MG>4#$*#A`2J@XPPPC>5@[__K`%!0XA(``+H!`(7B=.__ZP!`4.(0```*#!"=
MY04@H.$P[__K!`"@X0`PH.,%,,3G`CJ-XAPP@^(`()/E`#"6Y0,`4N$&```:
M`MJ-XB#0C>)P@+WH``"@X_3__^H$`*#A\O__ZC3O_^LPP0(`M&X!``$0``"H
M;@$`P___ZO!/+>D!VDWBR#&?Y1S03>(!*HWB`#"3Y10@@N(`0*#A`6"@X;`!
MG^40$(WB`#""Y1+^_^LO$*#C`%"@X00`H.%@[__K``!0XPT```H$$*#AB`&?
MY5S^_^L$`*#A`3J-XA0P@^(`()/E:#&?Y0`PD^4#`%+A5@``&@':C>(<T(WB
M\(^]Z`0`H.%([__K4!&?Y0"0H.$&`*#A>N__ZP"P4.+I__\*/'&?Y3R!G^4\
MH9_E/&&?Y0`PV^4``%/C!["@`0``5>,$```*"Q"@X04`H.'0[O_K``!0XRX`
M``H+`*#A,N__ZP`PB^`!,%/E+P!3XP<``!H!,$#B`S"+X`#`H.,`P,/E`1!S
MY0$`0.(O`%'C^O__"@$PB>(``(/@"`!0X<G__\K,,)_E`2J@XP$0H.,(0(WE
M!*"-Y0"PC>44`(WB)N__ZP``EN5R[__K%!"-XE(O@.(#`*#C7.__ZP``4.,%
M```:``"6Y6KO_^M8,9#E#SH#X@()4^,*```*8!"?Y0``H.,_[__K`+"@X0``
M6^/'__\:K/__ZD00G^4Y[__K`+"@X?C__^H!$*#C%`"-XC'O_^L``%#C[___
M&A00C>(8`)_E`/[_ZQ0`C>()[__KH?__ZKGN_^LPP0(`O&X!`,AN`0#8;@$`
MN&X!`/\/``#D;@$`.,$"`-QN`0``,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!
M,-+D``!3X_K__QH>_R_A<$`MZ0!`4.(I```*`%#4Y0``5>,F```*V^[_ZP$`
M0.(`((3@`@!4X0L``"H`,-3G+P!3XR<``!H!,$+B`P``Z@`0T^4!,$/B+P!1
MXR$``!H$`%/A`R"@X?C__QH"`%3A)P``"@$@0N($``#J`##2Y0$00N(O`%/C
M`@``&@$@H.$"`%3A^/__.@(@9.`",(+B`0I3XPT``(H!((+B!!"@X0$ZH.-L
M`)_E>.[_ZV0`G^5P@+WH`@"@XZ'N_^L``%#C`@``"BXPH..P,,#A<("]Z```
MH.-P@+WH`3!"X@,``.H`$-/E`3!#XB\`4>/<__\*`P!4X0,@H.'X__\Z`@!4
MX=?__QHO`%7CZ?__"@@`G^5P0+WHKN[_ZES!`@#D;@$`,$`MZ3303>)(X9_E
M","-XD1!G^4/`+[H`%"4Y0\`K.@/`+[H+%"-Y0#@GN4/`*SH*`&?Y;#@S.%P
M_?_K(`&?Y6[]_^L<`9_E;/W_ZQ@!G^5J_?_K%`&?Y6C]_^L0`9_E9OW_ZPP!
MG^5D_?_K"`&?Y6+]_^L$`9_E8/W_ZP`!G^5>_?_K_`"?Y5S]_^OX`)_E6OW_
MZ_0`G^58_?_K!!"-XNP`G^4D_?_K`!!0X@$```K(`)_E<_W_ZP00C>+4`)_E
M'?W_ZP`04.(!```*R`"?Y6S]_^L$$(WBP`"?Y1;]_^L`$%#B"@``"H@`G^5E
M_?_KK!"?Y70`G^5B_?_K+""=Y0`PE.4#`%+A$0``&C30C>(P@+WH!!"-XH@`
MG^4&_?_K`!!0X@(```I,`)_E5?W_Z^[__^H*(*#C;!"?Y1D`C>*4[O_K``!0
MX^C__QHC$(WB]/__Z@CN_^OL;0$`,,$"`.AN`0#T;@$`_&X!``AO`0`0;P$`
M(&\!`+QN`0`L;P$`.&\!`$1O`0#(;@$`4&\!`%QO`0!H;P$`?&\!`)!O`0"<
M;P$`S&\!`*QO`0#`;P$`,$`MZ0S03>)@4)_E8$"?Y0``E>4`,)3E`0!PXP0P
MC>4%```*!""=Y0`PE.4#`%+A#0``&@S0C>(P@+WH#1"@X3``G^70_/_K``!0
MXP0```H``-#E,`!0XP``4!,!`*`3``"@`P``A>7M___JUNW_ZR#!`@`PP0(`
M+&\!`!!`+>FP[?_KJ>W_ZP``4.,``)`5$("]Z/!'+>D`<*#A]."?Y3C03>(8
MP(WB#P"^Z.B`G^4/`*SH!P">Z!A`G>4`,)CE``!4XP<`C.@T,(WE%P``"LB0
MG^484(WB!@``Z@<0H.&,[?_K``!0XQ8```H$0+7E``!4XPT```H4$(WB!`"@
MX:'\_^L`8%#B`@``"@`PUN4``%/C\/__&@0`H.$'$*#A[/S_ZP1`M>4``%3C
M\?__&C0@G>4`,)CE`P!2X10``!HXT(WB\(>]Z`<`H.':[?_K`*"@X08`H.'7
M[?_K``"*X`(`@.+"[?_K"&"-Y8`"C>@L,)_E`"#@XP$0H.,`H*#AV>W_ZPH0
MH.$$`*#AT?S_Z]7__^J,[?_K$&X!`##!`@#8;@$`W&X!`-@XG^7P3RWI`%"@
MX8'<3>('`)/H/-!-XD#`C>(,0(/B!P",Z"3`@^(/`+3H6."-XDQ@C>(/`*[H
M`P"4Z*`XG^4#`([H!P"<Z(',C>(`,)/E-,",X@<`AN@\$(WBA`B?Y0`PC.5>
M_/_K`$!0X@(```H`,-3E``!3XP,!`!J4___K`'!0XDQ`C0)'```*!P"@X9_M
M_^N``*#A`0"`XHKM_^L`,-?E``!3XP!@H.$`0*`1"0``"@`PC>4$`*#A*#B?
MY0`@X.,!$*#CG>W_ZP$P]^4"0(3B``!3X_7__QI8`)WE``!0XUA`C1(#```:
M$```Z@0`M.4``%#C#0``"CP0C>(W_/_K`'!0XOC__PH`,-?E``!3X_7__PI8
M_?_K``!0X_+__PH'`*#AB^W_ZP"@4.(I```:0$"=Y0``5.,E```*`##4Y0``
M4^,!<*`3"0``&B```.I./XWB!S&#X/A`$^4``%3C&P``"@`PU.4!<(?B``!3
MXQ<```H$`*#A/_W_ZP``4./R__\*!`"@X7+M_^L``%#C[O__"@"@H.$.``#J
M;>W_ZP``4..U```:!`"4Y```4..X```*/!"-X@C\_^L`,%#B^/__"@`PT^4`
M`%/C]?__"O'__^H`H*#C"@"@X4OM_^L$EY_E`$"@X08`H.%'[?_K``"$X`%+
M@.($0(3B!`"@X3#M_^OD-I_E`"#@XP@PC>4!$*#CV#:?Y0Q@C>4`H(WE!)"-
MY0"`H.%$[?_K"`"@X0<=H.--[?_K`0!PXQH```JP9I_E``"6Y8KM_^L($*#A
M4B^`X@,`H..`[?_K``!0XQ\```J0)I_E`#"5Y0$0H.,`@(WE``"2Y8`FG^5-
M[?_K``"@XX$\C>(T,(/B`""3Y4@VG^4`,)/E`P!2X<0!`!J!W(WB/-"-XO"/
MO>@@[?_K`""0Y1$`4N/@__\*.!:?Y0`PE>4$((WE-":?Y0``D>4`@(WE`1"@
MXS;M_^L``*#CY___Z@``EN5B[?_K6#&0Y0\Z`^(!"5/CV?__&@``EN5<[?_K
M8'&0Y:/L_^L``%?AT___&@``EN56[?_K6#&0Y8,[H.$.`E/CS?__&@0`H.'D
M[/_K/!"-X@!`H.'$!9_EIOO_ZP``4.-5```*`&"5Y0#M_^L`$*#A!@"@X7_]
M_^L`8%#B3@``"@8`H.'G[/_K`P!0XP!PH.$+``#:!`!`X@``AN"`%9_E>NS_
MZP``4.,%```:!`!7XRP!``H'<(;@!3!7Y2\`4^,H`0`*J/[_ZP`04.($```:
M!@"@X;[L_^L`,%#B(#"-Y3<``!H\%9_E/`6?Y=3[_^O&[/_K1'6?Y0`#C>@,
M<(WE*#6?Y0`@X.,!$*#C`&"@XP@`C>4$`*#ASNS_ZPX``.K)[/_K`#"0Y1$`
M4^,0```:MNS_ZP%@AN(,8(WE$'"-Y0`#C>@%(*#AY#2?Y0$0H.,(`(WE!`"@
MX;[L_^L'':#C!`"@X<?L_^L!`'#C`%"@X>K__PH(`*#A4^S_ZP00H.%T!)_E
MKOO_ZP0`H.&;_O_K!`"@X8#__^H`<*#A__[_ZI;^_^L$`*#AL.S_ZWK__^J`
M=)_E#0"@X_S^_^H`8)7EKO__Z@)0H.,`,.#C$2#@XP!0C>5U[/_K31^-X@8@
MH.,@`)WE+^S_ZS0QW>4``%/C`@``&C4QW>5#`%/C$0$`"@!0H.,`(*#C`#"@
MXP!0C>4@`)WE9>S_Z^L_C^+0(,/AZQ^/XM``P>'K?X_BT&#'X?@GS>'J/X_B
MT"##X>J_C^+0H,OA\`?-X0``H.,`$*#C\"G-X:@PC>+H4(WE\&C-X?BHS>'X
M"<WA\`K-X20PC>4H@(WE+)"-Y0(IH.--'XWB(`"=Y0?L_^L`4%#B4```VM@)
MS>&%@:#A`'"@XP!@F.`'`%'A!@!0`04@H.'%/Z#AT`K-X0$``)H!`)#B`!"A
MXJ+.H.&#P8SAHSZ@X1PPC>48P(WEV*'-X>@PG>7X:<WA`*":X`&PJ^`*`*#A
M"Q"@X0``4^/P"LWA,P``"D!P8^('`%7A)""=Y05PH+$#`(+@31^-X@<@H.'Q
MZ__KZ#"=Y0,PA^!``%/CZ#"-Y='__QI-/XWB<`"-X@509^`'<(/@:^W_ZS\`
M5>,8``#:0+"'X@6@H.%`8$OBJ."-X@``EN4$$);E"""6Y0PPEN4.P*#A$&"&
MX@L`5N$/`*SH#."@X?7__QI`H$KB<`"-XECM_^L_`%KC0+"&XNW__\I`4$7B
M)3.@X0$@@^(#4T7@`G.'X`<0H.%(,*#C!2"@X20`G>7QZ__KZ%"-Y:K__^I-
M?XWBV___ZB``G>4H@)WE+)"=Y6'L_^N84)WEJ'"-XG\@X..E,:#A/S`#X@$0
M@^(X`%'CH&"=Y0,@Q^=D``#*`0"'X#@@8>(`$*#C'>S_ZR8\H.$FR*#A)A2@
MX24LH.%P`(WBYU#-Y>`PS>4E.*#A)52@X>-@S>7AP,WEXA#-Y>0@S>7E,,WE
MYE#-Y27M_^MPX)WE>,"=Y8``G>4N6*#A+CR@X??@S>4NY*#A]N#-Y2SLH.&(
M$)WE^\#-Y?C@S>4LZ*#A+,2@X?K`S>4@S*#AD""=Y?\`S>7\P,WE(,B@X2`$
MH.'^`,WE(0R@X0,1S>4``<WE(0B@X2$4H.$"$<WE(AR@X4*OC>(!`<WE!R'-
MY4X/C>($$<WE(AB@X2(DH.'U4,WE]##-Y?G@S>7]P,WE"E"@X?1@C>(%$<WE
M,7!`X@8AS>4```#J`3#VY0`PC>4%`*#AV#"?Y0`@X.,!$*#CR>O_ZP8`5^$"
M4(7B]?__&OPPG^4``*#C##"-Y3`!S>4`!XWH`"#@X^@PG^4!$*#C!`"@X;SK
M_^L"___J!%"5Y0``5>/3_O\*!0"@X:KK_^L#`%#CS_[_F@0`0.(``(7@J!"?
MY3[K_^L``%#C!6"@`<C^_^I`(&'B`0"'X``0H..XZ__K<`"-XL[L_^L'`*#A
M.""@XP`0H..RZ__KD___ZHFKS>\``````2-%9P````#^W+J8`````/#ATL,`
M````=E0R$``````L;@$`,,$"`+QN`0#8;P$`Y&X!`.QO`0#@;P$`.,$"`$#!
M`@!T<`$`]&\!`,!Q`0`P<`$`S&\!`"QO`0!0<`$`8'`!`-!O`0`X<`$`;'$!
M`$!P`0`V,=WE00!3X^K^_QHW,=WE0P!3X^?^_QHX,=WE2`!3X^3^_QHY,=WE
M10!3X^'^_QH`4(WE(%"=Y0`PX.,Y(.#C!0"@X4?K_^M-'XWB!0"@X2D@H.,!
MZ__K:#`?Y4TOC>((((WE##"-Y0`#C>AX,!_E`"#@XP$0H.,$`*#A8^O_ZZG^
M_^H9Z__K@#.?Y?!/+>D,T$WB>'.?Y0`PD^4``)?E!#"-Y:?K_^L!,*#C#1"@
MX64PP.5<`Y_E_/G_ZP``4.,"```*`##0Y3$`4^.&```*I_S_ZP``E^6:Z__K
M"S"@XP$@H.,P$Y_E,.O_ZRQCG^4``%#C+@``"A`@D.7T/Q;E`0!3XQB`DN4I
M``#:`).?Y0!0H.,!0*#C"0``ZA`0D>4+`*#AQ^K_Z_0_%N4``%#C'```&@%`
MA.($`%/A`5"%XA@``-H``)?E?NO_ZP`PH.,%(*#A"!"@X5GK_^L`H%#B#P``
M"@`0FN6T,I_E\`\6Y0C`D>4,,`/@`0M3XP2QD.?E__\*``"9Y6[K_^L`$)KE
M`C"@XP`@H./LZO_K`!"@X=[__^KT/Q;E`2!#X@4`4N%!```*``"7Y6+K_^L#
M,*#C`2"@XUP2G^7XZO_K0%*?Y0!`4.(*```*``"5Y5GK_^L0,)3E0"*?Y0`0
MD^7.ZO_K$#"4Y0`PD^4(,)/E`043XW,``!H``)?E3NO_ZP,PH.,!(*#C%!*?
MY>3J_^OP09_E`%!0X@H```H-$*#A``*?Y9[Y_^L`@%#B``"4Y4P```I`Z__K
M$#"5Y0@@H.$`$)/EM>K_ZP``E^4ZZ__K`#"@XPT0H.&HD9_EL(&?Y64PP.7`
M`9_EC?G_ZP``4.,`0*#A[`\&Y1P```H'':#CZ^K_ZP$P@.(1`%#C`0!3$U4`
M`(IH,9_E!""=Y0`PD^4#`%+A3P``&@S0C>+PC[WH`0!3X[O__]H!0*#C``"7
MY1WK_^L($*#A;>K_Z_0_%N4!0(3B!`!3X??__\JQ___J`3#0Y0``4^-V__\*
M=/__ZO`/&.7Q_/_K``!0X^P/".4V```*$""5Y0@QG^4`()+E"!"2Y0$P`^`!
M"U/C(0``&A``DN7P3Q;E!!"@X5KJ_^L0()7EW#"?Y0!`E.4`()+E"!"2Y0$P
M`^`!"U/C`&"@X0L``!H0()+E!C"@X000H.'(`)_EJ>K_Z_/J_^OP+Q;E$#"5
MY0`0DN4``)/EC_K_Z[#__^H``)?EZ^K_ZQ`0E>4`(*#C`C"@XP`0D>5HZO_K
M`""@X>O__^H``)GEXNK_ZQ`0E>4$(*#A`C"@XP`0D>5?ZO_KUO__Z@``E>7:
MZO_K$#"4Y0`0D^6AZO_KA?__ZDP`G^6)ZO_K/>K_Z_`?&.4`,*#A!""@X0`0
MD>4T`)_E@NK_ZS#!`@`XP0(`$&\!`,AP`0!0X0(```0@`-!P`0#4<`$`W'`!
M`,AN`0"\;@$`!'$!`.!P`0`L<0$`<$`MZ0!0H.%_^__K`##0Y0!`H.$``%/C
M!0``"@$@@.(O`%/C`D"@`0$PTN0``%/C^O__&BC\_^L``%7C``!0$W"`O0@`
M,-7E``!3XW"`O0@8$)_E!`"@X>7I_^L``%3A<("]&`4`H.%P0+WHU?G_ZNQO
M`0`,,)_E`S"/X```4^,`,),5"NK_ZKA3`0#X0RWI`'"@X4A@G^5(4)_E!F"/
MX`50C^`&8&7@`8"@X0*0H.''Z?_K1F&PX?B#O0@`0*#C`4"$X@0PE>0'`*#A
M"!"@X0D@H.$S_R_A!@!4X??__QKX@[WH6%$!`%!1`0`>_R_A"$`MZ0B`O>@!
M``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````H'$!`+!Q`0"X<0$`P'$!`,AQ`0#<<0$``````)AQ`0"X;@$`````
M`)!O`0"4;P$`C'$!`,!N`0"4<0$``````'AQ`0"`<0$``````"5S+R5S````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!
M4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$52
M3#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!0
M05)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,
M7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``
M,0```%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@`````8````<&5R;```
M```P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%
M35!$25(`5$U0`"]T;7``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"
M4D%265]0051(`````$193$1?3$E"4D%265]0051(````4TA,24)?4$%42```
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@
M)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'
M5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.
M5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*
M)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.
M5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I
M9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S
M970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS
M965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R
M96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD
M:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED
M>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J
M(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`[
M"B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII
M9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L
M;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@
M)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D[
M"G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO
M<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N
M;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A
M(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@
M)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F
M:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@
M=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?
M1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O
M7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E
M<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE;F=T:"@D
M82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@
M)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E
M('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M`(!J_W\!````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````,&P$`Y!H!````
M```!`````0````$```#3`0```0```-X!```!````Z`$```$````W`@```0``
M`(H#```!````L`,```P```"X%`$`#0```-1M`0`9````W+X"`!L````$````
M&@```."^`@`<````!````/7^_V^T`0$`!0```"0,`0`&````9`4!``H````4
M!0``"P```!`````5``````````,`````P`(``@```!`"```4````$0```!<`
M``"H$@$`$0```'`2`0`2````.````!,````(````_O__;Q`2`0#___]O`P``
M`/#__V\X$0$`````````````````````````````````````````````````
M````````````````Z+X"````````````Q!0!`,04`0#$%`$`Q!0!`,04`0#$
M%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04
M`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!
M`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`
MQ!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$
M%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04`0#$%`$`Q!0!`,04
M`0#$%`$`Q!0!`,04`0#$%`$`````````````````_____^AQ`0!'0T,Z("A2
M87-P8FEA;B`U+C,N,2TU*W)P:3$I(#4N,RXQ(#(P,38P,3`Q`$=#0SH@*%)A
M<W!B:6%N(#0N.2XS+3$P*2`T+CDN,P!!+@```&%E86)I``$D````!38`!@8(
M`0D!"@(2!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB
M=71E<P``````````````````````````````````````````````````````
M"P````$````"````5`$!`%0!```9```````````````!`````````!,````'
M`````@```'`!`0!P`0``(```````````````!``````````A````!P````(`
M``"0`0$`D`$``"0```````````````0`````````-````/;__V\"````M`$!
M`+0!``"P`P``!0`````````$````!````#X````+`````@```&0%`0!D!0``
MP`8```8````!````!````!````!&`````P````(````D#`$`)`P``!0%````
M``````````$`````````3@```/___V\"````.!$!`#@1``#8````!0``````
M```"`````@```%L```#^__]O`@```!`2`0`0$@``8`````8````#````!```
M``````!J````"0````(```!P$@$`<!(``#@````%``````````0````(````
M<P````D```!"````J!(!`*@2```0`@``!0```!8````$````"````'P````!
M````!@```+@4`0"X%```#```````````````!`````````!W`````0````8`
M``#$%`$`Q!0``"P#``````````````0````$````@@````$````&````\!<!
M`/`7``#D50`````````````(`````````(@````!````!@```-1M`0#4;0``
M"```````````````!`````````".`````0````(```#<;0$`W&T``,!!````
M``````````0`````````E@````$``'""````G*\!`)RO```(````#0``````
M```$`````````*$````!`````@```*2O`0"DKP``!```````````````!```
M``````"K````#@````,```#<O@(`W+X```0```````````````0`````````
MMP````\````#````X+X"`."^```$```````````````$`````````,,````!
M`````P```.2^`@#DO@``!```````````````!`````````#(````!@````,`
M``#HO@(`Z+X``!@!```&``````````0````(````T0````$````#`````,`"
M``#````8`0`````````````$````!````-8````!`````P```!C!`@`8P0``
M$```````````````!`````````#<````"`````,````HP0(`*,$``$00````
M``````````@`````````X0````$````P`````````"C!``!+````````````
M```!`````0```.H````#``!P``````````!SP0``+P```````````````0``
M```````!`````P``````````````HL$``/H```````````````$`````````
